@@ -27,6 +27,9 @@ from idecomp.decomp.modelos.dadger import (
     CI,
     CE,
     FC,
+    EA,
+    ES,
+    QI,
     TI,
     RQ,
     EZ,
@@ -152,6 +155,9 @@ class Dadger(RegisterFile):
         CI,
         CE,
         FC,
+        EA,
+        ES,
+        QI,
         TI,
         RQ,
         EZ,
@@ -219,24 +225,6 @@ class Dadger(RegisterFile):
         r = self.__obtem_registros(tipo)
         return r[0] if len(r) > 0 else None
 
-    def __obtem_registro_com_codigo(
-        self, tipo: Type[T], codigo: int
-    ) -> Optional[T]:
-        regs: List[Any] = self.__registros_por_tipo(tipo)
-        for r in regs:
-            if r.codigo == codigo:
-                return r
-        return None
-
-    def __obtem_registro_do_estagio(
-        self, tipo: Type[T], codigo: int, estagio: int
-    ) -> Optional[T]:
-        regs: List[Any] = self.__registros_por_tipo(tipo)
-        for r in regs:
-            if all([r.codigo == codigo, r.estagio == estagio]):
-                return r
-        return None
-
     def __obtem_registros(self, tipo: Type[T]) -> List[T]:
         return self.__registros_por_tipo(tipo)
 
@@ -789,6 +777,48 @@ class Dadger(RegisterFile):
             FC, tipo=tipo, caminho=caminho
         )
 
+    def ea(self, ree: Optional[int] = None) -> Optional[Union[EA, List[EA]]]:
+        """
+        Obtém um registro que especifica a ENA dos meses anteriores
+        ao estudo.
+
+        :param ree: Código do REE
+        :type ree: int | None
+        :return: Um ou mais registros, se existirem.
+        :rtype: :class:`EA` | list[:class:`EA`] | None
+        """
+        return self.__obtem_registros_com_filtros(EA, ree=ree)
+
+    def es(
+        self, ree: Optional[int] = None, numero_semanas: Optional[int] = None
+    ) -> Optional[Union[ES, List[ES]]]:
+        """
+        Obtém um registro que especifica a ENA das semanas anteriores
+        ao estudo.
+
+        :param ree: Código do REE
+        :type ree: int | None
+        :param numero_semanas: Número de semanas do mês anterior
+        :type numero_semanas: int | None
+        :return: Um ou mais registros, se existirem.
+        :rtype: :class:`ES` | list[:class:`ES`] | None
+        """
+        return self.__obtem_registros_com_filtros(
+            ES, ree=ree, numero_semanas=numero_semanas
+        )
+
+    def qi(self, uhe: Optional[int] = None) -> Optional[Union[QI, List[QI]]]:
+        """
+        Obtém um registro que especifica o tempo de viagem
+        para cálculo da ENA.
+
+        :param uhe: Código da UHE
+        :type uhe: int | None
+        :return: Um ou mais registros, se existirem.
+        :rtype: :class:`QI` | list[:class:`QI`] | None
+        """
+        return self.__obtem_registros_com_filtros(QI, uhe=uhe)
+
     def ti(
         self, codigo: Optional[int] = None
     ) -> Optional[Union[TI, List[TI]]]:
